@@ -22,7 +22,7 @@ from awscli.paramfile import get_paramfile, ResourceLoadingError
 from awscli.paramfile import PARAMFILE_DISABLED
 from awscli import shorthand
 from awscli.utils import find_service_and_method_in_event_name
-
+from botocore.utils import is_json_value_header
 
 LOG = logging.getLogger('awscli.argprocess')
 
@@ -166,8 +166,19 @@ def unpack_cli_arg(cli_argument, value):
                            cli_argument.cli_name)
 
 
+def _special_type(model):
+    # check if model is jsonvalue header and that value is serializable
+    if model.serialization.get('jsonvalue') and \
+       model.serialization.get('location') == 'header' and \
+       model.type_name == 'string':
+        return True
+    return False
+
+
 def _unpack_cli_arg(argument_model, value, cli_name):
-    if argument_model.type_name in SCALAR_TYPES:
+    if is_json_value_header(argument_model):
+        return _unpack_json_cli_arg(argument_model, value, cli_name)
+    elif argument_model.type_name in SCALAR_TYPES:
         return unpack_scalar_cli_arg(
             argument_model, value, cli_name)
     elif argument_model.type_name in COMPLEX_TYPES:
@@ -177,6 +188,15 @@ def _unpack_cli_arg(argument_model, value, cli_name):
         return six.text_type(value)
 
 
+def _unpack_json_cli_arg(argument_model, value, cli_name):
+    try:
+        return json.loads(value, object_pairs_hook=OrderedDict)
+    except ValueError as e:
+        raise ParamError(
+            cli_name, "Invalid JSON: %s\nJSON received: %s"
+            % (e, value))
+
+
 def _unpack_complex_cli_arg(argument_model, value, cli_name):
     type_name = argument_model.type_name
     if type_name == 'structure' or type_name == 'map':
